pub struct ProcessGroup<M>where
M: Message,{ /* private fields */ }Available on crate feature
actor only.Expand description
A group of actors that share messages using a routing Strategy.
Implementations
Sourceimpl<M> ProcessGroup<M>where
M: Message,
impl<M> ProcessGroup<M>where
M: Message,
Sourcepub fn new() -> ProcessGroup<M>
pub fn new() -> ProcessGroup<M>
Creates an empty process group.
Sourcepub fn with_strategy(strategy: Strategy) -> ProcessGroup<M>
pub fn with_strategy(strategy: Strategy) -> ProcessGroup<M>
Creates an empty process group with a routing strategy.
Sourcepub fn join(&self, broker: Broker<M>) -> Membership<M>
pub fn join(&self, broker: Broker<M>) -> Membership<M>
Adds a broker until the returned membership is dropped.
Sourcepub fn send(&self, message: M) -> Result<(), DeliverError<M>>
pub fn send(&self, message: M) -> Result<(), DeliverError<M>>
Routes a message to the next available member.